/***********************************************************************************************************************************
Fork Handler
***********************************************************************************************************************************/
#ifndef COMMON_FORK_H
#define COMMON_FORK_H

/***********************************************************************************************************************************
Functions
***********************************************************************************************************************************/
void forkDetach(void);

#endif
